# Changelog

<!--next-version-placeholder-->

## v0.7.0 (2021-12-30)
### Feature
* More CI fun ([#13](https://github.com/msalib/py-geo-rasterize/issues/13)) ([`a2c69ab`](https://github.com/msalib/py-geo-rasterize/commit/a2c69abd218f2a7e8b395f1873d237185cd18355))

## v0.6.0 (2021-12-30)
### Feature
* Whatever again ([#12](https://github.com/msalib/py-geo-rasterize/issues/12)) ([`127c872`](https://github.com/msalib/py-geo-rasterize/commit/127c87266b21c2b5948d7b6f473f88c7828087b0))
* Whatever ([#11](https://github.com/msalib/py-geo-rasterize/issues/11)) ([`65263f4`](https://github.com/msalib/py-geo-rasterize/commit/65263f4ab35d6feeae35e90b8bd164c6d97ac560))
* You know, CI fun ([#10](https://github.com/msalib/py-geo-rasterize/issues/10)) ([`6508b0f`](https://github.com/msalib/py-geo-rasterize/commit/6508b0f0d381f0a7d2b982ebebe0739e39273c02))
* Time to give up on not repeating myself ([#9](https://github.com/msalib/py-geo-rasterize/issues/9)) ([`a8d915f`](https://github.com/msalib/py-geo-rasterize/commit/a8d915f2b4cba81b9a1027843311f3250b072523))

## v0.5.0 (2021-12-30)
### Feature
* We really are getting closer to better CI ([#8](https://github.com/msalib/py-geo-rasterize/issues/8)) ([`85a2a29`](https://github.com/msalib/py-geo-rasterize/commit/85a2a295091202e2049519f8931cc820b452f4b2))

## v0.4.0 (2021-12-30)
### Feature
* More semver joy ([#7](https://github.com/msalib/py-geo-rasterize/issues/7)) ([`5707289`](https://github.com/msalib/py-geo-rasterize/commit/57072894e4a74d91e9bb3e856bfafd42a17e3e29))

## v0.3.0 (2021-12-30)
### Feature
* I swear, CI is getting better ([#6](https://github.com/msalib/py-geo-rasterize/issues/6)) ([`f4425cc`](https://github.com/msalib/py-geo-rasterize/commit/f4425ccf7dc60e21a07051c6783358f3ab662dcf))

## v0.1.0 (2021-12-30)
### Feature
* More CI improvements ([#4](https://github.com/msalib/py-geo-rasterize/issues/4)) ([`c517df4`](https://github.com/msalib/py-geo-rasterize/commit/c517df4a454eaba847090ccdef6093c834e35a03))
* Add windows and macos builds to CI ([#3](https://github.com/msalib/py-geo-rasterize/issues/3)) ([`5e54cb6`](https://github.com/msalib/py-geo-rasterize/commit/5e54cb67e00484c89f674b208bde18242abe05a3))
* Try to fix CI release ([#2](https://github.com/msalib/py-geo-rasterize/issues/2)) ([`eaf0f2f`](https://github.com/msalib/py-geo-rasterize/commit/eaf0f2f3ff16ecb169b8614d8eff723dd03577d8))
* Many small improvements ([#1](https://github.com/msalib/py-geo-rasterize/issues/1)) ([`fc970a8`](https://github.com/msalib/py-geo-rasterize/commit/fc970a873174b6a34adfa910a41b624b444a2883))
